@@ -1,3 +1,15 @@
+"""
+Module for loading configuration for the application.
+
+It selects the environment to load based on the following environment variables:
+- ARCHIMEDES_ENVIRONMENT
+- ENVIRONMENT
+
+ARCHIMEDES_ENVIRONMENT takes precedence over ENVIRONMENT.
+
+If none of the above environment variables are set, it defaults to "prod".
+"""
+
 import abc
 import logging
 import os
