@@ -1,9 +1,11 @@
 """
 A collection of functions for integrating with the Archimedes API
 """
-import json
+# pylint: disable=no-member
+
 from http import HTTPStatus
 
+import orjson
 import requests
 from requests.exceptions import (  # pylint:disable=redefined-builtin
     ConnectionError,
@@ -78,7 +80,7 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
         response = retry_call(
             self.session.request,
             fargs=(method, url),
-            fkwargs=dict(headers=headers, timeout=timeout, **kwargs),
+            fkwargs={"headers": headers, "timeout": timeout, **kwargs},
             tries=retry_count + 1,
             delay=retry_delay,
             exceptions=RETRY_EXCEPTIONS,
@@ -92,7 +94,7 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
                 elif "detail" in response_json:
                     error_message = response_json.get("detail")
                 else:
-                    error_message = json.dumps(response_json)
+                    error_message = response.text
             except JSONDecodeError:
                 error_message = response.content
             params_str = str(kwargs.get("params"))
@@ -102,7 +104,13 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
                 f"{error_message}"
             )
 
-        return response.json()
+        logger.debug(
+            "Response from Archimedes for API (url: %s, kwargs: %s): %s",
+            url,
+            kwargs,
+            response.text[:250],
+        )
+        return orjson.loads(response.text)
 
 
 api = ArchimedesApi()
